const { series } = require('gulp');
const gulp = require('gulp');
const fs = require('fs');
const del = require('del');
const inlineStr = require('gulp-inline-str');
const babel = require('gulp-babel');
const uglify = require('gulp-uglify');
const concat = require('gulp-concat');

const babelOptions = JSON.parse(fs.readFileSync('./.babelrc', 'utf8'));

const paths = {
  scripts: [
    'src/index.js',
    'src/getDeviceId.js',
    'src/havePropsChanged.js',
    'src/errors.js',
    'src/createBlob.js',
  ],
  worker: 'src/worker.js',
  jsQR: 'node_modules/jsqr/dist/jsQR.js',
  type: 'src/index.d.ts',
  destination: './dist',
};

function clean() {
  return del([paths.destination + '/*.js']);
}

function worker() {
  return gulp
    .src([paths.jsQR, paths.worker])
    .pipe(concat('worker.js'))
    .pipe(uglify())
    .pipe(gulp.dest(paths.destination));
}

function build() {
  return gulp
    .src(paths.scripts)
    .pipe(inlineStr({ basePath: paths.destination }))
    .pipe(babel(babelOptions))
    .pipe(gulp.dest(paths.destination));
}

function copy() {
  return gulp.src(paths.type).pipe(gulp.dest(paths.destination));
}

function watch() {
  gulp.watch(paths.scripts, series(clean, worker, build, copy));
}

exports.watch = series(watch);
exports.default = series(clean, worker, build, copy);
